summaryrefslogtreecommitdiff
path: root/Master/texmf/scripts
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2012-06-10 01:21:30 +0000
committerKarl Berry <karl@freefriends.org>2012-06-10 01:21:30 +0000
commit51f501a3211cb68f46e6d446f1395f5ec14704b8 (patch)
treeb7eabb37e511d7a5293016bdfaff7bfb0da1dfb0 /Master/texmf/scripts
parent788b637a28c1d3266b42b3d6309fc94f464ab2e9 (diff)
regen updmap doc
git-svn-id: svn://tug.org/texlive/trunk@26882 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/texmf/scripts')
-rwxr-xr-xMaster/texmf/scripts/tetex/updmap.pl75
1 files changed, 39 insertions, 36 deletions
diff --git a/Master/texmf/scripts/tetex/updmap.pl b/Master/texmf/scripts/tetex/updmap.pl
index 29ee87ea87f..08822b6debc 100755
--- a/Master/texmf/scripts/tetex/updmap.pl
+++ b/Master/texmf/scripts/tetex/updmap.pl
@@ -1,6 +1,6 @@
#!/usr/bin/env perl
# mupdmap: utility to maintain map files for outline fonts.
-# $Id: updmap.pl 26878 2012-06-10 00:21:51Z preining $
+# $Id: updmap.pl 26881 2012-06-10 01:18:51Z karl $
#
# Copyright 2011, 2012 Norbert Preining
# This file is licensed under the GNU General Public License version 2
@@ -33,7 +33,7 @@ BEGIN {
}
-my $version = '$Id: updmap.pl 26878 2012-06-10 00:21:51Z preining $';
+my $version = '$Id: updmap.pl 26881 2012-06-10 01:18:51Z karl $';
use Getopt::Long qw(:config no_autoabbrev ignore_case_always);
use strict;
@@ -265,40 +265,40 @@ sub main {
# updmap (user):
# ==============
# as found:
- # TEXMFCONFIG $HOME/.texlive2012/texmf-config/web2c/updmap.cfg
- # TEXMFVAR $HOME/.texlive2012/texmf-var/web2c/updmap.cfg
+ # TEXMFCONFIG $HOME/.texliveYYYY/texmf-config/web2c/updmap.cfg
+ # TEXMFVAR $HOME/.texliveYYYY/texmf-var/web2c/updmap.cfg
# TEXMFHOME $HOME/texmf/web2c/updmap.cfg
# TEXMFSYSCONFIG $TEXLIVE/2012/texmf-config/web2c/updmap.cfg
# TEXMFSYSVAR $TEXLIVE/2012/texmf-var/web2c/updmap.cfg
# TEXMFMAIN $TEXLIVE/2012/texmf/web2c/updmap.cfg
# TEXMFLOCAL $TEXLIVE/texmf-local/web2c/updmap.cfg
- # TEXMFDIST $TEXLIVE/2012/texmf-dist/web2c/updmap.cfg
+ # TEXMFDIST $TEXLIVE/YYYY/texmf-dist/web2c/updmap.cfg
#
# as used:
- # TEXMFCONFIG $HOME/.texlive2012/texmf-config/web2c/updmap.cfg
- # TEXMFVAR $HOME/.texlive2012/texmf-var/web2c/updmap.cfg
+ # TEXMFCONFIG $HOME/.texliveYYYY/texmf-config/web2c/updmap.cfg
+ # TEXMFVAR $HOME/.texliveYYYY/texmf-var/web2c/updmap.cfg
# TEXMFHOME $HOME/texmf/web2c/updmap.cfg
- # TEXMFSYSCONFIG $TEXLIVE/2012/texmf-config/web2c/updmap.cfg
- # TEXMFSYSVAR $TEXLIVE/2012/texmf-var/web2c/updmap.cfg
+ # TEXMFSYSCONFIG $TEXLIVE/YYYY/texmf-config/web2c/updmap.cfg
+ # TEXMFSYSVAR $TEXLIVE/YYYY/texmf-var/web2c/updmap.cfg
# TEXMFLOCAL $TEXLIVE/texmf-local/web2c/updmap.cfg
- # TEXMFMAIN $TEXLIVE/2012/texmf/web2c/updmap.cfg
- # TEXMFDIST $TEXLIVE/2012/texmf-dist/web2c/updmap.cfg
+ # TEXMFMAIN $TEXLIVE/YYYY/texmf/web2c/updmap.cfg
+ # TEXMFDIST $TEXLIVE/YYYY/texmf-dist/web2c/updmap.cfg
#
# updmap-sys (root):
# ==================
# as found:
# TEXMFSYSCONFIG $TEXLIVE/2012/texmf-config/web2c/updmap.cfg
# TEXMFSYSVAR $TEXLIVE/2012/texmf-var/web2c/updmap.cfg
# TEXMFMAIN $TEXLIVE/2012/texmf/web2c/updmap.cfg
# TEXMFLOCAL $TEXLIVE/texmf-local/web2c/updmap.cfg
- # TEXMFDIST $TEXLIVE/2012/texmf-dist/web2c/updmap.cfg
+ # TEXMFDIST $TEXLIVE/YYYY/texmf-dist/web2c/updmap.cfg
#
# as used:
- # TEXMFSYSCONFIG $TEXLIVE/2012/texmf-config/web2c/updmap.cfg
- # TEXMFSYSVAR $TEXLIVE/2012/texmf-var/web2c/updmap.cfg
+ # TEXMFSYSCONFIG $TEXLIVE/YYYY/texmf-config/web2c/updmap.cfg
+ # TEXMFSYSVAR $TEXLIVE/YYYY/texmf-var/web2c/updmap.cfg
# TEXMFLOCAL $TEXLIVE/texmf-local/web2c/updmap.cfg
- # TEXMFMAIN $TEXLIVE/2012/texmf/web2c/updmap.cfg
- # TEXMFDIST $TEXLIVE/2012/texmf-dist/web2c/updmap.cfg
+ # TEXMFMAIN $TEXLIVE/YYYY/texmf/web2c/updmap.cfg
+ # TEXMFDIST $TEXLIVE/YYYY/texmf-dist/web2c/updmap.cfg
#
if ($found || $old_updmap_local_found) {
my @tmp;
@@ -2057,23 +2057,26 @@ Explanation of trees and files normally used:
Thus, if updmap.cfg files are present in all trees, and the default
layout is used as shipped with TeX Live, the following files are
- read in this order:
- updmap-sys variant:
- TEXMFSYSCONFIG \$TEXLIVE/2012/texmf-config/web2c/updmap.cfg
- TEXMFSYSVAR \$TEXLIVE/2012/texmf-var/web2c/updmap.cfg
+ read in the given order.
+
+ For updmap-sys:
+ TEXMFSYSCONFIG \$TEXLIVE/YYYY/texmf-config/web2c/updmap.cfg
+ TEXMFSYSVAR \$TEXLIVE/YYYY/texmf-var/web2c/updmap.cfg
TEXMFLOCAL \$TEXLIVE/texmf-local/web2c/updmap.cfg
- TEXMFMAIN \$TEXLIVE/2012/texmf/web2c/updmap.cfg
- TEXMFDIST \$TEXLIVE/2012/texmf-dist/web2c/updmap.cfg
+ TEXMFMAIN \$TEXLIVE/YYYY/texmf/web2c/updmap.cfg
+ TEXMFDIST \$TEXLIVE/YYYY/texmf-dist/web2c/updmap.cfg
- updmap variant:
- TEXMFCONFIG \$HOME/.texlive2012/texmf-config/web2c/updmap.cfg
- TEXMFVAR \$HOME/.texlive2012/texmf-var/web2c/updmap.cfg
+ For updmap:
+ TEXMFCONFIG \$HOME/.texliveYYYY/texmf-config/web2c/updmap.cfg
+ TEXMFVAR \$HOME/.texliveYYYY/texmf-var/web2c/updmap.cfg
TEXMFHOME \$HOME/texmf/web2c/updmap.cfg
- TEXMFSYSCONFIG \$TEXLIVE/2012/texmf-config/web2c/updmap.cfg
- TEXMFSYSVAR \$TEXLIVE/2012/texmf-var/web2c/updmap.cfg
+ TEXMFSYSCONFIG \$TEXLIVE/YYYY/texmf-config/web2c/updmap.cfg
+ TEXMFSYSVAR \$TEXLIVE/YYYY/texmf-var/web2c/updmap.cfg
TEXMFLOCAL \$TEXLIVE/texmf-local/web2c/updmap.cfg
- TEXMFMAIN \$TEXLIVE/2012/texmf/web2c/updmap.cfg
- TEXMFDIST \$TEXLIVE/2012/texmf-dist/web2c/updmap.cfg
+ TEXMFMAIN \$TEXLIVE/YYYY/texmf/web2c/updmap.cfg
+ TEXMFDIST \$TEXLIVE/YYYY/texmf-dist/web2c/updmap.cfg
+
+ (where YYYY is the TeX Live release version).
There is another exception to keep upgradability from earlier versions of
TeX Live: if a file TEXMFLOCAL/web2c/updmap-local.cfg exists (formerly
@@ -2090,7 +2093,7 @@ Explanation of trees and files normally used:
line, then the first one given will be used to save any changes from
--setoption, --enable or --disable. If the config files are taken
from kpsewhich output, then the algorithm is more complex:
- 1) If \$TEXMFHOME/web2c/updmap.cfg or \$TEXMFCONFIG/web2c/updmap.cfg
+ 1) If \$TEXMFCONFIG/web2c/updmap.cfg or \$TEXMFHOME/web2c/updmap.cfg
appears in the list of used files, then the one listed first by
kpsewhich --all (equivalently, the one returned by kpsewhich
updmap.cfg), is used.
@@ -265,40 +265,40 @@ sub main {
# TEXMFHOME $HOME/texmf/web2c/updmap.cfg
- # TEXMFSYSCONFIG $TEXLIVE/2012/texmf-config/web2c/updmap.cfg
- # TEXMFSYSVAR $TEXLIVE/2012/texmf-var/web2c/updmap.cfg
- # TEXMFMAIN $TEXLIVE/2012/texmf/web2c/updmap.cfg
+ # TEXMFSYSCONFIG $TEXLIVE/YYYY/texmf-config/web2c/updmap.cfg
+ # TEXMFSYSVAR $TEXLIVE/YYYY/texmf-var/web2c/updmap.cfg
+ # TEXMFMAIN $TEXLIVE/YYYY/texmf/web2c/updmap.cfg
# TEXMFLOCAL $TEXLIVE/texmf-local/web2c/updmap.cfg
@@ -265,40 +265,40 @@ sub main {
# ==================
# as found:
- # TEXMFSYSCONFIG $TEXLIVE/2012/texmf-config/web2c/updmap.cfg
- # TEXMFSYSVAR $TEXLIVE/2012/texmf-var/web2c/updmap.cfg
- # TEXMFMAIN $TEXLIVE/2012/texmf/web2c/updmap.cfg
+ # TEXMFSYSCONFIG $TEXLIVE/YYYY/texmf-config/web2c/updmap.cfg
+ # TEXMFSYSVAR $TEXLIVE/YYYY/texmf-var/web2c/updmap.cfg
+ # TEXMFMAIN $TEXLIVE/YYYY/texmf/web2c/updmap.cfg
# TEXMFLOCAL $TEXLIVE/texmf-local/web2c/updmap.cfg